{% load fullpath %}

<script src="{% static_fullpath request 'cf_orange/jquery-1.7.1.min.js' %}" type="text/javascript"></script>

<div id="widgetvisualization-{{widget.pk}}" rel="{{widget.pk}}" class="widgetvisualizationdialog"
     title="{{widget.name}} visualization" style="height:600px; width:800px;">


    {% url 'nltk get adc index' widget_id=widget.pk as path %}
    <iframe src="{% fullpath request path %}" width="100%" height="95%"></iframe>

    {% url 'nltk get adc index' widget_id=widget.pk narrow_doc='' as path %}
    <div style="position:absolute; bottom:10px; left:590px;">
        <a target="_blank" style="color: gray;" href="{% fullpath request path %}">Open corpus view in new window</a>
    </div>
</div>
